<?php
namespace Teknisa\FIS\Services;

use DateTime;
use Doctrine\ORM\EntityManager;
use Teknisa\FIS\Factories\Fis27100RelacionamentodeCodigodaReceitaFactory;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Row;

class Fis27100RelacionamentodeCodigodaReceitaService {

    protected $nrorg;
    protected $operador;
    protected $currentTime;
    protected $environment;
    protected $entityManager;
    protected $dataSourceManager;
    protected $factory;
    protected $newCode;

    public function __construct($environment, $entityManager, $dataSourceManager, $factory, newCode $newCode) {
        $this->environment       = $environment;
        $this->entityManager     = $entityManager;
        $this->dataSourceManager = $dataSourceManager;
        $this->factory           = $factory;
        $this->newCode           = $newCode;
        $this->nrorg             = $this->entityManager->getNrOrg();
        $this->operador          = $this->entityManager->getCdOperador();
        $this->currentTime       = $this->entityManager->getCurrentTime()->format("d/m/Y H:i:s");
    }

    public function geraNovoCodigo($contador, $nrorg){
        try {
            return $this->newCode->getCodeByTableName($contador, $nrorg);
        }catch (\Exception $e) {
            throw $e;        }
    }
    
    
    public function save($row){
        
        if($row['__is_new']){
            if($row['IDTIPO'] == 'F'){
                 $result = $this->factory->buscaFornecedor($row['CDFORNECED']);
                 if(!empty($result)){
                     throw new \Exception("Fornecedor já cadastrado");
                }else {
                    $this->factory->save(array(
                        "NRORG"             => $this->nrorg,
                        "NRSEQCDRECPART"    =>  $this->geraNovoCodigo('NRSEQCDRECPART',$this->nrorg),
                        "IDTIPO"            => $row['IDTIPO'],
                        "CDFORNECED"        => $row['CDFORNECED'],
                        "CDCLIENTE"         => null,
                        "CDFILIAL"          => null,
                        "CDIMPOSTO"         => $row['CDIMPOSTO'],
                        "CDRECEITA"         => $row['CDRECEITACONTR'],
                            
                        ));
                }
            }else if($row['IDTIPO'] == 'C'){
                 $result = $this->factory->buscaCliente($row['CDCLIENTE']);
                 if(!empty($result)){
                     throw new \Exception("Cliente já cadastrado");
                 }else{
                     $this->factory->save(array(
                        "NRORG"             => $this->nrorg,
                        "NRSEQCDRECPART"    =>  $this->geraNovoCodigo('NRSEQCDRECPART',$this->nrorg),
                        "IDTIPO"            => $row['IDTIPO'],
                        "CDFORNECED"        => null,
                        "CDCLIENTE"         => $row['CDCLIENTE'],
                        "CDFILIAL"          => null,
                        "CDIMPOSTO"         => $row['CDIMPOSTO'],
                        "CDRECEITA"         => $row['CDRECEITACONTR'],
                            
                    ));
                 }
            }else{
                $result = $this->factory->buscaFilial($row['CDFILIAL']);
                 if(!empty($result)){
                     throw new \Exception("Filial já cadastrado");
                 }else{
                     $this->factory->save(array(
                        "NRORG"             => $this->nrorg,
                        "NRSEQCDRECPART"    =>  $this->geraNovoCodigo('NRSEQCDRECPART',$this->nrorg),
                        "IDTIPO"            => $row['IDTIPO'],
                        "CDFORNECED"        => null,
                        "CDCLIENTE"         => null,
                        "CDFILIAL"          => $row['CDFILIAL'],
                        "CDIMPOSTO"         => $row['CDIMPOSTO'],
                        "CDRECEITA"         => $row['CDRECEITACONTR'],
                            
                    ));
                }
            }
          //  var_dump($row);die;
             
            }
     
    }
    
    public function update($row){
        
        if($row[0]['__is_new'] == false){
            //var_dump($row);die;
                  if($row[0]['IDTIPO'] == 'F'){
                        $this->factory->save(array(
                            "NRORG"             => $this->nrorg,
                            "NRSEQCDRECPART"    => $this->geraNovoCodigo('NRSEQCDRECPART',$this->nrorg),
                            "IDTIPO"            => $row[0]['IDTIPO'],
                            "CDFORNECED"        => $row[0]['CDFORNECED'],
                            "CDCLIENTE"         => null,
                            "CDFILIAL"          => null,
                            "CDIMPOSTO"         => $row[1]['CDIMPOSTO'],
                            "CDRECEITA"         => $row[1]['CDRECEITACONTR'],
                                
                            ));
                    
                }else if($row[0]['IDTIPO'] == 'C'){
                         $result = $this->factory->buscaCliente($row[0]['CDCLIENTE']);
                    //     var_dump($row[1]['CDRECEITA']);die;
                         
                       
                       //  var_dump($result);die;
                         $this->factory->save(array(
                            "NRORG"             => $this->nrorg,
                            "NRSEQCDRECPART"    => $this->geraNovoCodigo('NRSEQCDRECPART',$this->nrorg),
                            "IDTIPO"            => $row[0]['IDTIPO'],
                            "CDFORNECED"        => null,
                            "CDCLIENTE"         => $row[0]['CDCLIENTE'],
                            "CDFILIAL"          => null,
                            "CDIMPOSTO"         => $row[1]['CDIMPOSTO'],
                            "CDRECEITA"         => $row[1]['CDRECEITACONTR'],
                                
                        ));
                     
                }else{
                         $this->factory->save(array(
                            "NRORG"             => $this->nrorg,
                            "NRSEQCDRECPART"    => $this->geraNovoCodigo('NRSEQCDRECPART',$this->nrorg),
                            "IDTIPO"            => $row[0]['IDTIPO'],
                            "CDFORNECED"        => null,
                            "CDCLIENTE"         => null,
                            "CDFILIAL"          => $row[0]['CDFILIAL'],
                            "CDIMPOSTO"         => $row[1]['CDIMPOSTO'],
                            "CDRECEITA"         => $row[1]['CDRECEITACONTR'],
                                
                        ));
                }
            }
        }
        
    public function saveimposto($row){
        
        if($row['__is_new'] == false){
            $this->factory->updateimposto(array(
                            "CDIMPOSTO"         => $row['CDIMPOSTO'],
                            "CDRECEITA"         => $row['CDRECEITACONTR'],
                                
                            ));
        }
        $this->factory->saveimposto(array(
                            "NRORG"             => $this->nrorg,
                            "CDIMPOSTO"         => $row['CDIMPOSTO'],
                            "CDRECEITA"         => $row['CDRECEITACONTR'],
                                
                            ));
                    
    }


}